==> jc-1.4.0.tar.gz: gnu/java/nio/charset/UTF__5f16Encoder.h <==
// final class gnu.java.nio.charset.UTF_16Encoder

// class file dependencies
// @dep_class 41701da00a96627b gnu_java_nio_charset_UTF__5f16Encoder
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 702d6146848c5569 java_nio_charset_CharsetEncoder

// header file dependencies
// @dep_header java_nio_charset_CharsetEncoder

#include "java/nio/charset/CharsetEncoder.h"

#ifndef _JC_gnu_java_nio_charset_UTF__5f16Encoder_H_
#define _JC_gnu_java_nio_charset_UTF__5f16Encoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$refs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object	_jc_gnu_java_nio_charset_UTF__5f16Encoder$object;

typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct	_jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype;

// Class fields structure
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct {
	jint	BIG__5fENDIAN;
	jint	LITTLE__5fENDIAN;
	jchar	BYTE__5fORDER__5fMARK;
};
extern _jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$class_fields;

// Constructors
extern void _jc_gnu_java_nio_charset_UTF__5f16Encoder$method$_init$e0d974c8036de73c(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_charset_Charset$object *, jint, jboolean);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_UTF__5f16Encoder$method$encodeLoop$2ce0cadadd176638(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *);
extern void _jc_gnu_java_nio_charset_UTF__5f16Encoder$method$implReset$7614bfe5fe6326d0(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *);
extern void _jc_gnu_java_nio_charset_UTF__5f16Encoder$method$put$30a3690f132de52f(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_ByteBuffer$object *, jchar);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Encoder$method_info$encodeLoop$2ce0cadadd176638;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Encoder$method_info$implReset$7614bfe5fe6326d0;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Encoder$method_info$put$30a3690f132de52f;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*encodeLoop$2ce0cadadd176638)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *);
	void	(*implReset$7614bfe5fe6326d0)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *);
	void	(*put$30a3690f132de52f)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_ByteBuffer$object *, jchar);
};

// Vtable
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetEncoder$vmethods	java_nio_charset_CharsetEncoder;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods	gnu_java_nio_charset_UTF__5f16Encoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$refs {
    _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs	gnu_java_nio_charset_UTF__5f16Encoder;
    _jc_java_nio_charset_CharsetEncoder$sub_refs	java_nio_charset_CharsetEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs {
	jint	byteOrder;
	jboolean	useByteOrderMark;
	jboolean	needsByteOrderMark;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetEncoder$sub_nonrefs	java_nio_charset_CharsetEncoder;
    _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs	gnu_java_nio_charset_UTF__5f16Encoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object {
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype _jc_gnu_java_nio_charset_UTF__5f16Encoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_UTF__5f16Encoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_UTF__5f16Encoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_UTF__5f16Encoder_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/charset/UTF__5f16Encoder.h <==
// final class gnu.java.nio.charset.UTF_16Encoder

// class file dependencies
// @dep_class da1c81d3b8dad7ef gnu_java_nio_charset_UTF__5f16Encoder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 50801be894e42472 java_nio_charset_CharsetEncoder

// header file dependencies
// @dep_header java_nio_charset_CharsetEncoder

#include "java/nio/charset/CharsetEncoder.h"

#ifndef _JC_gnu_java_nio_charset_UTF__5f16Encoder_H_
#define _JC_gnu_java_nio_charset_UTF__5f16Encoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_ByteOrder$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$refs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object	_jc_gnu_java_nio_charset_UTF__5f16Encoder$object;

typedef struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct	_jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype;

// Class fields structure
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct {
	jint	BIG__5fENDIAN;
	jint	LITTLE__5fENDIAN;
	jchar	BYTE__5fORDER__5fMARK;
};
extern _jc_gnu_java_nio_charset_UTF__5f16Encoder$fields_struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$class_fields;

// Constructors
extern void _jc_gnu_java_nio_charset_UTF__5f16Encoder$method$_init$e0d974c8036de73c(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_charset_Charset$object *, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_UTF__5f16Encoder$method$encodeLoop$2ce0cadadd176638(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_charset_UTF__5f16Encoder$method$implReset$7614bfe5fe6326d0(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Encoder$method_info$encodeLoop$2ce0cadadd176638;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Encoder$method_info$implReset$7614bfe5fe6326d0;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*encodeLoop$2ce0cadadd176638)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
	void	(*implReset$7614bfe5fe6326d0)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetEncoder$vmethods	java_nio_charset_CharsetEncoder;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vmethods	gnu_java_nio_charset_UTF__5f16Encoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs {
	struct _jc_java_nio_ByteOrder$object	*byteOrder;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$refs {
    _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_refs	gnu_java_nio_charset_UTF__5f16Encoder;
    _jc_java_nio_charset_CharsetEncoder$sub_refs	java_nio_charset_CharsetEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs {
	jboolean	useByteOrderMark;
	jboolean	needsByteOrderMark;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetEncoder$sub_nonrefs	java_nio_charset_CharsetEncoder;
    _jc_gnu_java_nio_charset_UTF__5f16Encoder$sub_nonrefs	gnu_java_nio_charset_UTF__5f16Encoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_UTF__5f16Encoder$object {
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_UTF__5f16Encoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_UTF__5f16Encoder$vtype _jc_gnu_java_nio_charset_UTF__5f16Encoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_UTF__5f16Encoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_UTF__5f16Encoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_UTF__5f16Encoder_H_ */
